var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { BleManager as RNBleManager, LogLevel } from "react-native-ble-plx";
import { awaitsBleOn } from "./awaitsBleOn";
import { getBluetoothServiceUuids } from "@ledgerhq/devices";
export class BlePlxManager {
    static get instance() {
        if (!this._instance) {
            this._instance = new RNBleManager();
        }
        return this._instance;
    }
    static waitOn() {
        return awaitsBleOn(BlePlxManager.instance);
    }
    static getKnownDevice(identifier) {
        return __awaiter(this, void 0, void 0, function* () {
            const devices = yield this.instance.devices([identifier]);
            return devices[0];
        });
    }
    static getConnectedDevices() {
        return this.instance.connectedDevices(getBluetoothServiceUuids());
    }
    static connect(identifier, options = {}) {
        return this.instance.connectToDevice(identifier, options);
    }
    /**
     * Exposed method from the ble-plx library
     * Sets new log level for native module's logging mechanism.
     * @param logLevel
     */
    static setLogLevel(logLevel) {
        return __awaiter(this, void 0, void 0, function* () {
            if (Object.values(LogLevel).includes(logLevel)) {
                yield this.instance.setLogLevel(logLevel);
            }
            else {
                throw new Error(`${logLevel} is not a valid LogLevel`);
            }
        });
    }
    static onStateChange(listener, emitCurrentState) {
        return this.instance.onStateChange(listener, emitCurrentState);
    }
    static startScan(callback) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.instance.startDeviceScan(getBluetoothServiceUuids(), null, (error, device) => {
                callback(error, device);
            });
        });
    }
    static stopScan() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.instance.stopDeviceScan();
        });
    }
    static disconnectDevice(deviceIdentifier) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.instance.cancelDeviceConnection(deviceIdentifier);
        });
    }
    static cancelTransaction(transactionId) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.instance.cancelTransaction(transactionId);
        });
    }
}
//# sourceMappingURL=BlePlxManager.js.map